@@ -25,6 +25,11 @@
 #include <KLocalizedString>
 #include <kwidgetsaddons_version.h>
 
+#include <knotifications_export.h>
+#if KNOTIFICATIONS_BUILD_DEPRECATED_SINCE(5, 79)
+#include <QDesktopWidget>
+#endif
+
 // Qt
 #include <QApplication>
 #include <QDate>
@@ -34,7 +39,6 @@
 #include <QColorDialog>
 #include <QDBusServiceWatcher>
 #include <QDebug>
-#include <QDesktopWidget>
 #include <QFileDialog>
 #include <QUrl>
 #include <QProcess>
@@ -49,10 +53,8 @@
 #include <X11/Xutil.h>
 #endif
 
-#ifdef Qt5DBus_FOUND
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
-#endif
 
 #include <unistd.h>
 #include <QCommandLineParser>
@@ -77,7 +79,7 @@ public:
     }
 
 protected:
-    bool eventFilter(QObject *o, QEvent *e) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *o, QEvent *e) override;
 private:
     bool print;
     WId id;
@@ -87,7 +89,7 @@ bool WinIdEmbedder::eventFilter(QObject *o, QEvent *e)
 {
     if (e->type() == QEvent::Show && o->isWidgetType()
         && o->inherits("QDialog")) {
-        auto *w = static_cast<QWidget *>(o);
+        auto w = static_cast<QWidget *>(o);
         if (print) {
             cout << "winId: " << w->winId() << endl;
         }
@@ -107,7 +109,6 @@ bool WinIdEmbedder::eventFilter(QObject *o, QEvent *e)
  */
 static bool sendVisualNotification(const QString &text, const QString &title, const QString &icon, int timeout)
 {
-#ifdef Qt5DBus_FOUND
     const QString dbusServiceName = QStringLiteral("org.freedesktop.Notifications");
     const QString dbusInterfaceName = QStringLiteral("org.freedesktop.Notifications");
     const QString dbusPath = QStringLiteral("/org/freedesktop/Notifications");
@@ -154,7 +155,7 @@ static bool sendVisualNotification(const QString &text, const QString &title, co
     } else {
         //kDebug() << "Unexpected reply type";
     }
-#endif
+
     return false;
 }
 
@@ -255,9 +256,10 @@ int main(int argc, char *argv[])
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("kdialog");
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     // enable high dpi support
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
+#endif
     KAboutData aboutData(QStringLiteral("kdialog"), i18n("KDialog"),
                          QStringLiteral(KDIALOG_VERSION_STRING), i18n("KDialog can be used to show nice dialog boxes from shell scripts"),
                          KAboutLicense::GPL,
@@ -419,11 +421,11 @@ int main(int argc, char *argv[])
         icon = QMessageBox::Warning;
     } else if (parser.isSet(QStringLiteral("sorry"))) {
         option = "sorry";
-        type = KMessageBox::Sorry;
+        type = KMessageBox::Error;
         icon = QMessageBox::Warning;
     } else if (parser.isSet(QStringLiteral("detailedsorry"))) {
         option = "detailedsorry";
-        type = KMessageBox::Sorry;
+        type = KMessageBox::Error;
         icon = QMessageBox::Warning;
     } else if (parser.isSet(QStringLiteral("error"))) {
         option = "error";
@@ -475,7 +477,7 @@ int main(int argc, char *argv[])
 
         QDialog dialog;
         dialog.setWindowTitle(title);
-        auto *buttonBox = new QDialogButtonBox(&dialog);
+        auto buttonBox = new QDialogButtonBox(&dialog);
         KMessageBox::Options options = KMessageBox::NoExec;
 
         switch (type) {
@@ -497,7 +499,6 @@ int main(int argc, char *argv[])
             KGuiItem::assign(buttonBox->button(QDialogButtonBox::Yes), continueButton);
             KGuiItem::assign(buttonBox->button(QDialogButtonBox::No), cancelButton);
             break;
-        case KMessageBox::Sorry:
         case KMessageBox::Error:
         case KMessageBox::Information:
             buttonBox->addButton(QDialogButtonBox::Ok);
@@ -519,7 +520,7 @@ int main(int argc, char *argv[])
         if (!dontagain.isEmpty()) {
             // We use NoExec in order to call handleXGeometry before exec
             // But that means we need to query the state of the dontShowAgain checkbox ourselves too...
-            auto *cb = dialog.findChild<QCheckBox *>();
+            auto cb = dialog.findChild<QCheckBox *>();
             Q_ASSERT(cb);
             if (cb && cb->isChecked()) {
                 if (type == KMessageBox::WarningContinueCancel) {
@@ -579,18 +580,22 @@ int main(int argc, char *argv[])
         }
 
         // Use --icon parameter for passivepopup as well
-        QString icon;
+        QString iconArg;
         if (parser.isSet(QStringLiteral("icon"))) {
-            icon = parser.value(QStringLiteral("icon"));
+            iconArg = parser.value(QStringLiteral("icon"));
         } else {
-            icon = QStringLiteral("dialog-information");      // Use generic (i)-icon if none specified
+            iconArg = QStringLiteral("dialog-information");      // Use generic (i)-icon if none specified
         }
 
         // try to use more stylish notifications
-        if (sendVisualNotification(Utils::parseString(parser.value(QStringLiteral("passivepopup"))), title, icon, timeout)) {
+        const bool result = sendVisualNotification(Utils::parseString(parser.value(QStringLiteral("passivepopup"))), title, iconArg, timeout);
+        if (result) {
             return 0;
         }
 
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+#if KNOTIFICATIONS_BUILD_DEPRECATED_SINCE(5, 79)
         // ...did not work, use KPassivePopup as fallback
 
         // parse timeout time again, so it does not auto-close the fallback (timer cannot handle -1 time)
@@ -603,7 +608,7 @@ int main(int argc, char *argv[])
 
         QPixmap passiveicon;
         if (parser.isSet(QStringLiteral("icon"))) {  // Only show icon if explicitly requested
-            passiveicon = KIconLoader::global()->loadIcon(icon, KIconLoader::Dialog);
+            passiveicon = KIconLoader::global()->loadIcon(iconArg, KIconLoader::Dialog);
         }
         KPassivePopup *popup = KPassivePopup::message(KPassivePopup::Boxed,  // style
                                                       title,
@@ -611,7 +616,7 @@ int main(int argc, char *argv[])
                                                       passiveicon,
                                                       (QWidget *)nullptr, // parent
                                                       timeout);
-        auto *timer = new QTimer();
+        auto timer = new QTimer();
         QObject::connect(timer, SIGNAL(timeout()), qApp, SLOT(quit()));
         QObject::connect(popup, QOverload<>::of(&KPassivePopup::clicked), qApp, &QApplication::quit);
         timer->setSingleShot(true);
@@ -631,6 +636,8 @@ int main(int argc, char *argv[])
             popup->setAnchor(QPoint(x, y));
         }
 #endif
+#endif // KNOTIFICATIONS_BUILD_DEPRECATED
+QT_WARNING_POP
         qApp->exec();
         return 0;
     }
@@ -935,7 +942,7 @@ int main(int argc, char *argv[])
               : // end: KDE3 compatibility
                 /* else */ KIconLoader::Any;
 
-        KIconDialog dlg((QWidget *)Q_NULLPTR);
+        KIconDialog dlg;
         dlg.setup(group, context);
         dlg.setIconSize(KIconLoader::SizeHuge);
 
@@ -968,7 +975,7 @@ int main(int argc, char *argv[])
             arguments << args.at(0);
         }
         qint64 pid = 0;
-        if (process.startDetached(QStringLiteral("kdialog_progress_helper"), arguments, QString(), &pid)) {
+        if (process.startDetached(QStandardPaths::findExecutable(QStringLiteral("kdialog_progress_helper")), arguments, QString(), &pid)) {
             QDBusConnection dbus = QDBusConnection::sessionBus();
             const QString serviceName = QStringLiteral("org.kde.kdialog-") + QString::number(pid);
             QDBusServiceWatcher watcher(serviceName, dbus, QDBusServiceWatcher::WatchForRegistration);
